pub enum EpubGenerationError {
LibraryError(LibraryError),
EpubError {
msg: String,
cause: Error,
},
IoError {
msg: String,
cause: Error,
},
}Expand description
An error on epub generation
Variants
LibraryError(LibraryError)
Returned when an error related to library management occured
EpubError
Returned when an error related to epub generation occured
IoError
Returned when a filesystem-related error occurs